@@ -287,16 +287,14 @@ class KinovaGen3Arm(robot_arms.RobotArm):
         if velocity is not None and velocity > self.max_velocity:
             raise robot_arms.RobotArmInvalidVelocityError(f'Invalid velocity: {velocity} m/s, must be less than {self.max_velocity} m/s')
 
-        if frame is not None:
-            raise robot_arms.RobotArmNotSupportedError(f'Frame parameter not supported')
-
         self.logger.debug(f'move_to_location({location}, velocity={velocity}, acceleration={acceleration}, frame={frame}, '
                           f'relative={relative}, wait={wait}, timeout={timeout})')
 
         action = Base_pb2.Action()
 
         target_pose = action.reach_pose.target_pose
-        location_m = location.convert_mm_to_m() if self.position_units == Units.MILLIMETERS else location.copy()
+        relative_location = (frame or Location()) * location
+        location_m = relative_location.convert_mm_to_m() if self.position_units == Units.MILLIMETERS else relative_location.copy()
         current_location = self.location.convert_mm_to_m() if self.position_units == Units.MILLIMETERS else self.location.copy()
 
         if relative:
